==> mdpws-model-1.0.0-sources.jar: org/somda/sdc/mdpws/model/StreamDescriptionsType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * This element contains the declarations of all the stream types that apply to a given context.
 * 
 * <p>Java class for StreamDescriptionsType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StreamDescriptionsType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="Types" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *                 &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="StreamType" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}StreamTypeType" maxOccurs="unbounded"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="TargetNamespace" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StreamDescriptionsType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "types",
    "streamType"
})
public class StreamDescriptionsType implements Cloneable, CopyTo2, ToString2
{

    @XmlElement(name = "Types", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016")
    protected StreamDescriptionsType.Types types;
    @XmlElement(name = "StreamType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", required = true)
    protected List<StreamTypeType> streamType;
    @XmlAttribute(name = "TargetNamespace", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String targetNamespace;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the types property.
     * 
     * @return
     *     possible object is
     *     {@link StreamDescriptionsType.Types }
     *     
     */
    public StreamDescriptionsType.Types getTypes() {
        return types;
    }

    /**
     * Sets the value of the types property.
     * 
     * @param value
     *     allowed object is
     *     {@link StreamDescriptionsType.Types }
     *     
     */
    public void setTypes(StreamDescriptionsType.Types value) {
        this.types = value;
    }

    /**
     * Gets the value of the streamType property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the streamType property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getStreamType().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link StreamTypeType }
     * 
     * 
     */
    public List<StreamTypeType> getStreamType() {
        if (streamType == null) {
            streamType = new ArrayList<StreamTypeType>();
        }
        return this.streamType;
    }

    /**
     * Gets the value of the targetNamespace property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetNamespace() {
        return targetNamespace;
    }

    /**
     * Sets the value of the targetNamespace property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetNamespace(String value) {
        this.targetNamespace = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setStreamType(List<StreamTypeType> value) {
        this.streamType = null;
        if (value!= null) {
            List<StreamTypeType> draftl = this.getStreamType();
            draftl.addAll(value);
        }
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof StreamDescriptionsType) {
            final StreamDescriptionsType copy = ((StreamDescriptionsType) draftCopy);
            {
                Boolean typesShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.types!= null));
                if (typesShouldBeCopiedAndSet == Boolean.TRUE) {
                    StreamDescriptionsType.Types sourceTypes;
                    sourceTypes = this.getTypes();
                    StreamDescriptionsType.Types copyTypes = ((StreamDescriptionsType.Types) strategy.copy(LocatorUtils.property(locator, "types", sourceTypes), sourceTypes, (this.types!= null)));
                    copy.setTypes(copyTypes);
                } else {
                    if (typesShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.types = null;
                    }
                }
            }
            {
                Boolean streamTypeShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.streamType!= null)&&(!this.streamType.isEmpty())));
                if (streamTypeShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<StreamTypeType> sourceStreamType;
                    sourceStreamType = (((this.streamType!= null)&&(!this.streamType.isEmpty()))?this.getStreamType():null);
                    @SuppressWarnings("unchecked")
                    List<StreamTypeType> copyStreamType = ((List<StreamTypeType> ) strategy.copy(LocatorUtils.property(locator, "streamType", sourceStreamType), sourceStreamType, ((this.streamType!= null)&&(!this.streamType.isEmpty()))));
                    copy.setStreamType(copyStreamType);
                } else {
                    if (streamTypeShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.streamType = null;
                    }
                }
            }
            {
                Boolean targetNamespaceShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.targetNamespace!= null));
                if (targetNamespaceShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceTargetNamespace;
                    sourceTargetNamespace = this.getTargetNamespace();
                    String copyTargetNamespace = ((String) strategy.copy(LocatorUtils.property(locator, "targetNamespace", sourceTargetNamespace), sourceTargetNamespace, (this.targetNamespace!= null)));
                    copy.setTargetNamespace(copyTargetNamespace);
                } else {
                    if (targetNamespaceShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.targetNamespace = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new StreamDescriptionsType();
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            StreamDescriptionsType.Types theTypes;
            theTypes = this.getTypes();
            strategy.appendField(locator, this, "types", buffer, theTypes, (this.types!= null));
        }
        {
            List<StreamTypeType> theStreamType;
            theStreamType = (((this.streamType!= null)&&(!this.streamType.isEmpty()))?this.getStreamType():null);
            strategy.appendField(locator, this, "streamType", buffer, theStreamType, ((this.streamType!= null)&&(!this.streamType.isEmpty())));
        }
        {
            String theTargetNamespace;
            theTargetNamespace = this.getTargetNamespace();
            strategy.appendField(locator, this, "targetNamespace", buffer, theTargetNamespace, (this.targetNamespace!= null));
        }
        return buffer;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;sequence&gt;
     *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "any"
    })
    public static class Types implements Cloneable, CopyTo2, ToString2
    {

        @XmlAnyElement
        protected List<Element> any;
        @XmlAnyAttribute
        private Map<QName, String> otherAttributes = new HashMap<QName, String>();

        /**
         * Gets the value of the any property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the any property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getAny().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link Element }
         * 
         * 
         */
        public List<Element> getAny() {
            if (any == null) {
                any = new ArrayList<Element>();
            }
            return this.any;
        }

        /**
         * Gets a map that contains attributes that aren't bound to any typed property on this class.
         * 
         * <p>
         * the map is keyed by the name of the attribute and 
         * the value is the string value of the attribute.
         * 
         * the map returned by this method is live, and you can add new attribute
         * by updating the map directly. Because of this design, there's no setter.
         * 
         * 
         * @return
         *     always non-null
         */
        public Map<QName, String> getOtherAttributes() {
            return otherAttributes;
        }

        public void setAny(List<Element> value) {
            this.any = null;
            if (value!= null) {
                List<Element> draftl = this.getAny();
                draftl.addAll(value);
            }
        }

        public Object clone() {
            return copyTo(createNewInstance());
        }

        public Object copyTo(Object target) {
            final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE;
            return copyTo(null, target, strategy);
        }

        public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
            final Object draftCopy = ((target == null)?createNewInstance():target);
            if (draftCopy instanceof StreamDescriptionsType.Types) {
                final StreamDescriptionsType.Types copy = ((StreamDescriptionsType.Types) draftCopy);
                {
                    Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                    if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                        List<Element> sourceAny;
                        sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                        @SuppressWarnings("unchecked")
                        List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                        copy.setAny(copyAny);
                    } else {
                        if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                            copy.any = null;
                        }
                    }
                }
            }
            return draftCopy;
        }

        public Object createNewInstance() {
            return new StreamDescriptionsType.Types();
        }

        public String toString() {
            final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE;
            final StringBuilder buffer = new StringBuilder();
            append(null, buffer, strategy);
            return buffer.toString();
        }

        public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
            strategy.appendStart(locator, this, buffer);
            appendFields(locator, buffer, strategy);
            strategy.appendEnd(locator, this, buffer);
            return buffer;
        }

        public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
            {
                List<Element> theAny;
                theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
            }
            return buffer;
        }

    }

}

==> mdpws-model-1.0.1-sources.jar: org/somda/sdc/mdpws/model/StreamDescriptionsType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * This element contains the declarations of all the stream types that apply to a given context.
 * 
 * <p>Java class for StreamDescriptionsType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StreamDescriptionsType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="Types" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *                 &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="StreamType" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}StreamTypeType" maxOccurs="unbounded"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="TargetNamespace" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StreamDescriptionsType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "types",
    "streamType"
})
public class StreamDescriptionsType implements Cloneable, CopyTo2, ToString2
{

    @XmlElement(name = "Types", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016")
    protected StreamDescriptionsType.Types types;
    @XmlElement(name = "StreamType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", required = true)
    protected List<StreamTypeType> streamType;
    @XmlAttribute(name = "TargetNamespace", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String targetNamespace;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der types-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link StreamDescriptionsType.Types }
     *     
     */
    public StreamDescriptionsType.Types getTypes() {
        return types;
    }

    /**
     * Legt den Wert der types-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link StreamDescriptionsType.Types }
     *     
     */
    public void setTypes(StreamDescriptionsType.Types value) {
        this.types = value;
    }

    /**
     * Gets the value of the streamType property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the streamType property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getStreamType().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link StreamTypeType }
     * 
     * 
     */
    public List<StreamTypeType> getStreamType() {
        if (streamType == null) {
            streamType = new ArrayList<StreamTypeType>();
        }
        return this.streamType;
    }

    /**
     * Ruft den Wert der targetNamespace-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetNamespace() {
        return targetNamespace;
    }

    /**
     * Legt den Wert der targetNamespace-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetNamespace(String value) {
        this.targetNamespace = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setStreamType(List<StreamTypeType> value) {
        this.streamType = null;
        if (value!= null) {
            List<StreamTypeType> draftl = this.getStreamType();
            draftl.addAll(value);
        }
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof StreamDescriptionsType) {
            final StreamDescriptionsType copy = ((StreamDescriptionsType) draftCopy);
            {
                Boolean typesShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.types!= null));
                if (typesShouldBeCopiedAndSet == Boolean.TRUE) {
                    StreamDescriptionsType.Types sourceTypes;
                    sourceTypes = this.getTypes();
                    StreamDescriptionsType.Types copyTypes = ((StreamDescriptionsType.Types) strategy.copy(LocatorUtils.property(locator, "types", sourceTypes), sourceTypes, (this.types!= null)));
                    copy.setTypes(copyTypes);
                } else {
                    if (typesShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.types = null;
                    }
                }
            }
            {
                Boolean streamTypeShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.streamType!= null)&&(!this.streamType.isEmpty())));
                if (streamTypeShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<StreamTypeType> sourceStreamType;
                    sourceStreamType = (((this.streamType!= null)&&(!this.streamType.isEmpty()))?this.getStreamType():null);
                    @SuppressWarnings("unchecked")
                    List<StreamTypeType> copyStreamType = ((List<StreamTypeType> ) strategy.copy(LocatorUtils.property(locator, "streamType", sourceStreamType), sourceStreamType, ((this.streamType!= null)&&(!this.streamType.isEmpty()))));
                    copy.setStreamType(copyStreamType);
                } else {
                    if (streamTypeShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.streamType = null;
                    }
                }
            }
            {
                Boolean targetNamespaceShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.targetNamespace!= null));
                if (targetNamespaceShouldBeCopiedAndSet == Boolean.TRUE) {
                    String sourceTargetNamespace;
                    sourceTargetNamespace = this.getTargetNamespace();
                    String copyTargetNamespace = ((String) strategy.copy(LocatorUtils.property(locator, "targetNamespace", sourceTargetNamespace), sourceTargetNamespace, (this.targetNamespace!= null)));
                    copy.setTargetNamespace(copyTargetNamespace);
                } else {
                    if (targetNamespaceShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.targetNamespace = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new StreamDescriptionsType();
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            StreamDescriptionsType.Types theTypes;
            theTypes = this.getTypes();
            strategy.appendField(locator, this, "types", buffer, theTypes, (this.types!= null));
        }
        {
            List<StreamTypeType> theStreamType;
            theStreamType = (((this.streamType!= null)&&(!this.streamType.isEmpty()))?this.getStreamType():null);
            strategy.appendField(locator, this, "streamType", buffer, theStreamType, ((this.streamType!= null)&&(!this.streamType.isEmpty())));
        }
        {
            String theTargetNamespace;
            theTargetNamespace = this.getTargetNamespace();
            strategy.appendField(locator, this, "targetNamespace", buffer, theTargetNamespace, (this.targetNamespace!= null));
        }
        return buffer;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;sequence&gt;
     *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "any"
    })
    public static class Types implements Cloneable, CopyTo2, ToString2
    {

        @XmlAnyElement
        protected List<Element> any;
        @XmlAnyAttribute
        private Map<QName, String> otherAttributes = new HashMap<QName, String>();

        /**
         * Gets the value of the any property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the any property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getAny().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link Element }
         * 
         * 
         */
        public List<Element> getAny() {
            if (any == null) {
                any = new ArrayList<Element>();
            }
            return this.any;
        }

        /**
         * Gets a map that contains attributes that aren't bound to any typed property on this class.
         * 
         * <p>
         * the map is keyed by the name of the attribute and 
         * the value is the string value of the attribute.
         * 
         * the map returned by this method is live, and you can add new attribute
         * by updating the map directly. Because of this design, there's no setter.
         * 
         * 
         * @return
         *     always non-null
         */
        public Map<QName, String> getOtherAttributes() {
            return otherAttributes;
        }

        public void setAny(List<Element> value) {
            this.any = null;
            if (value!= null) {
                List<Element> draftl = this.getAny();
                draftl.addAll(value);
            }
        }

        public Object clone() {
            return copyTo(createNewInstance());
        }

        public Object copyTo(Object target) {
            final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE;
            return copyTo(null, target, strategy);
        }

        public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
            final Object draftCopy = ((target == null)?createNewInstance():target);
            if (draftCopy instanceof StreamDescriptionsType.Types) {
                final StreamDescriptionsType.Types copy = ((StreamDescriptionsType.Types) draftCopy);
                {
                    Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                    if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                        List<Element> sourceAny;
                        sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                        @SuppressWarnings("unchecked")
                        List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                        copy.setAny(copyAny);
                    } else {
                        if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                            copy.any = null;
                        }
                    }
                }
            }
            return draftCopy;
        }

        public Object createNewInstance() {
            return new StreamDescriptionsType.Types();
        }

        public String toString() {
            final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE;
            final StringBuilder buffer = new StringBuilder();
            append(null, buffer, strategy);
            return buffer.toString();
        }

        public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
            strategy.appendStart(locator, this, buffer);
            appendFields(locator, buffer, strategy);
            strategy.appendEnd(locator, this, buffer);
            return buffer;
        }

        public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
            {
                List<Element> theAny;
                theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
            }
            return buffer;
        }

    }

}
